@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.aws_ssm._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@charlesdotfish/smtp-credentials-cdk-construct",
-    "1.0.20",
+    "2.0.0",
     __name__[0:-6],
-    "smtp-credentials-cdk-construct@1.0.20.jsii.tgz",
+    "smtp-credentials-cdk-construct@2.0.0.jsii.tgz",
 )
 
 __all__ = [
